@@ -8,7 +8,7 @@
 //! let mut v = ValueFormat::new_with_name("dt0", ValueType::DateTime);
 //! v.push_day(FormatNumberStyle::Long);
 //! v.push_text(".");
-//! v.push_month(FormatNumberStyle::Long);
+//! v.push_month(FormatNumberStyle::Long, false);
 //! v.push_text(".");
 //! v.push_year(FormatNumberStyle::Long);
 //! v.push_text(" ");
@@ -27,7 +27,7 @@
 //! when opening the spreadsheet so typically nobody notices this.
 //!
 
-pub use crate::attrmap2::{AttrMap2, AttrMap2Trait};
+use crate::attrmap2::AttrMap2;
 
 use crate::style::stylemap::StyleMap;
 use crate::style::units::{
@@ -197,6 +197,14 @@ impl ValueFormat {
         self.styleuse
     }
 
+    pub(crate) fn attrmap(&self) -> &AttrMap2 {
+        &self.attr
+    }
+
+    pub(crate) fn attrmap_mut(&mut self) -> &mut AttrMap2 {
+        &mut self.attr
+    }
+
     /// Text style attributes.
     pub fn textstyle(&self) -> &AttrMap2 {
         &self.textstyle
@@ -421,16 +429,6 @@ impl ValueFormat {
     }
 }
 
-impl AttrMap2Trait for ValueFormat {
-    fn attrmap(&self) -> &AttrMap2 {
-        &self.attr
-    }
-
-    fn attrmap_mut(&mut self) -> &mut AttrMap2 {
-        &mut self.attr
-    }
-}
-
 /// Identifies the structural parts of a value format.
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
 pub enum FormatPartType {
@@ -466,16 +464,6 @@ pub struct FormatPart {
     content: Option<String>,
 }
 
-impl AttrMap2Trait for FormatPart {
-    fn attrmap(&self) -> &AttrMap2 {
-        &self.attr
-    }
-
-    fn attrmap_mut(&mut self) -> &mut AttrMap2 {
-        &mut self.attr
-    }
-}
-
 /// Flag for several PartTypes.
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
 pub enum FormatNumberStyle {
@@ -497,7 +485,7 @@ impl Display for FormatNumberStyle {
 pub enum FormatCalendarStyle {
     Gregorian,
     Gengou,
-    ROC,
+    Roc,
     Hanja,
     Hijri,
     Jewish,
@@ -509,7 +497,7 @@ impl Display for FormatCalendarStyle {
         match self {
             FormatCalendarStyle::Gregorian => write!(f, "gregorian"),
             FormatCalendarStyle::Gengou => write!(f, "gengou"),
-            FormatCalendarStyle::ROC => write!(f, "ROC"),
+            FormatCalendarStyle::Roc => write!(f, "ROC"),
             FormatCalendarStyle::Hanja => write!(f, "hanja"),
             FormatCalendarStyle::Hijri => write!(f, "hijri"),
             FormatCalendarStyle::Jewish => write!(f, "jewish"),
@@ -700,13 +688,26 @@ impl FormatPart {
         self.part_type
     }
 
+    pub fn attrmap(&self) -> &AttrMap2 {
+        &self.attr
+    }
+
+    pub fn attrmap_mut(&mut self) -> &mut AttrMap2 {
+        &mut self.attr
+    }
+
+    /// Adds an attribute.
+    pub fn set_attr(&mut self, name: &str, value: String) {
+        self.attr.set_attr(name, value);
+    }
+
     /// Returns a property or a default.
     pub fn attr_def<'a0, 'a1, S0, S1>(&'a1 self, name: S0, default: S1) -> &'a1 str
     where
         S0: Into<&'a0 str>,
         S1: Into<&'a1 str>,
     {
-        if let Some(v) = self.attr(name.into()) {
+        if let Some(v) = self.attr.attr(name.into()) {
             v
         } else {
             default.into()
@@ -786,7 +787,7 @@ impl FormatPart {
     /// Tries to format the given DateTime, and appends the result to buf.
     /// Uses chrono::strftime for the implementation.
     /// If this part does'nt match does nothing
-    #[allow(clippy::collapsible_if)]
+    #[allow(clippy::collapsible_else_if)]
     fn format_datetime(&self, buf: &mut String, d: &NaiveDateTime, h12: bool) {
         match self.part_type {
             FormatPartType::Day => {
